document.addEventListener('DOMContentLoaded', () => {
  // Sample data - in production this would come from an API
  const strategies = [
    {
      name: "Momentum Factor Strategy",
      source: "Quantpedia",
      sharpe: 1.8,
      sortino: 2.1,
      maxdd: -15.2,
      cagr: 12.5,
      description: "Momentum-based strategy focusing on trend following"
    },
    {
      name: "Mean Reversion ETF",
      source: "MQL5",
      sharpe: 1.6,
      sortino: 1.9,
      maxdd: -12.8,
      cagr: 10.2,
      description: "Statistical arbitrage approach using ETFs"
    }
  ];

  const strategiesGrid = document.querySelector('.strategies-grid');
  const metricSelect = document.getElementById('metricSelect');
  const timeframeSelect = document.getElementById('timeframeSelect');

  function renderStrategies(sortMetric = 'sharpe') {
    strategiesGrid.innerHTML = '';
    
    const sortedStrategies = [...strategies].sort((a, b) => b[sortMetric] - a[sortMetric]);
    
    sortedStrategies.forEach((strategy, index) => {
      const card = document.createElement('div');
      card.className = 'strategy-card';
      card.innerHTML = `
        <h3>${index + 1}. ${strategy.name}</h3>
        <p><strong>Source:</strong> ${strategy.source}</p>
        <p><strong>Sharpe Ratio:</strong> ${strategy.sharpe.toFixed(2)}</p>
        <p><strong>Sortino Ratio:</strong> ${strategy.sortino.toFixed(2)}</p>
        <p><strong>Max Drawdown:</strong> ${strategy.maxdd.toFixed(1)}%</p>
        <p><strong>CAGR:</strong> ${strategy.cagr.toFixed(1)}%</p>
        <p>${strategy.description}</p>
      `;
      strategiesGrid.appendChild(card);
    });
  }

  metricSelect.addEventListener('change', (e) => {
    renderStrategies(e.target.value);
  });

  timeframeSelect.addEventListener('change', () => {
    renderStrategies(metricSelect.value);
  });

  // Initial render
  renderStrategies();
});
